==> kubernetes-model-core-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/NodeConfigStatusBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class NodeConfigStatusBuilder extends NodeConfigStatusFluentImpl<NodeConfigStatusBuilder> implements VisitableBuilder<NodeConfigStatus,NodeConfigStatusBuilder>{
  public NodeConfigStatusBuilder() {
    this(false);
  }
  public NodeConfigStatusBuilder(Boolean validationEnabled) {
    this(new NodeConfigStatus(), validationEnabled);
  }
  public NodeConfigStatusBuilder(NodeConfigStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public NodeConfigStatusBuilder(NodeConfigStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new NodeConfigStatus(), validationEnabled);
  }
  public NodeConfigStatusBuilder(NodeConfigStatusFluent<?> fluent,NodeConfigStatus instance) {
    this(fluent, instance, false);
  }
  public NodeConfigStatusBuilder(NodeConfigStatusFluent<?> fluent,NodeConfigStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withActive(instance.getActive());
      fluent.withAssigned(instance.getAssigned());
      fluent.withError(instance.getError());
      fluent.withLastKnownGood(instance.getLastKnownGood());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public NodeConfigStatusBuilder(NodeConfigStatus instance) {
    this(instance,false);
  }
  public NodeConfigStatusBuilder(NodeConfigStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withActive(instance.getActive());
      this.withAssigned(instance.getAssigned());
      this.withError(instance.getError());
      this.withLastKnownGood(instance.getLastKnownGood());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  NodeConfigStatusFluent<?> fluent;
  Boolean validationEnabled;
  public NodeConfigStatus build() {
    NodeConfigStatus buildable = new NodeConfigStatus(fluent.getActive(),fluent.getAssigned(),fluent.getError(),fluent.getLastKnownGood());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-core-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/NodeConfigStatusBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class NodeConfigStatusBuilder extends NodeConfigStatusFluent<NodeConfigStatusBuilder> implements VisitableBuilder<NodeConfigStatus,NodeConfigStatusBuilder>{
  public NodeConfigStatusBuilder() {
    this(false);
  }
  public NodeConfigStatusBuilder(Boolean validationEnabled) {
    this(new NodeConfigStatus(), validationEnabled);
  }
  public NodeConfigStatusBuilder(NodeConfigStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public NodeConfigStatusBuilder(NodeConfigStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new NodeConfigStatus(), validationEnabled);
  }
  public NodeConfigStatusBuilder(NodeConfigStatusFluent<?> fluent,NodeConfigStatus instance) {
    this(fluent, instance, false);
  }
  public NodeConfigStatusBuilder(NodeConfigStatusFluent<?> fluent,NodeConfigStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new NodeConfigStatus());

    if (instance != null) {
      fluent.withActive(instance.getActive());
      fluent.withAssigned(instance.getAssigned());
      fluent.withError(instance.getError());
      fluent.withLastKnownGood(instance.getLastKnownGood());
      fluent.withActive(instance.getActive());
      fluent.withAssigned(instance.getAssigned());
      fluent.withError(instance.getError());
      fluent.withLastKnownGood(instance.getLastKnownGood());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public NodeConfigStatusBuilder(NodeConfigStatus instance) {
    this(instance,false);
  }
  public NodeConfigStatusBuilder(NodeConfigStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new NodeConfigStatus());

    if (instance != null) {
      this.withActive(instance.getActive());
      this.withAssigned(instance.getAssigned());
      this.withError(instance.getError());
      this.withLastKnownGood(instance.getLastKnownGood());
      this.withActive(instance.getActive());
      this.withAssigned(instance.getAssigned());
      this.withError(instance.getError());
      this.withLastKnownGood(instance.getLastKnownGood());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  NodeConfigStatusFluent<?> fluent;
  Boolean validationEnabled;
  public NodeConfigStatus build() {
    NodeConfigStatus buildable = new NodeConfigStatus(fluent.buildActive(),fluent.buildAssigned(),fluent.getError(),fluent.buildLastKnownGood());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
